@@ -1,4 +1,5 @@
 import logging
+import time
 
 import cv2
 import numpy as np
@@ -7,6 +8,8 @@ import pyautogui
 from smb3_eh_manip.settings import config
 from smb3_eh_manip.video_player import VideoPlayer
 
+CLEAR_SIGHTING_DURATION_SECONDS = 10
+
 
 class OpencvComputer:
     def __init__(
@@ -14,23 +17,30 @@ class OpencvComputer:
         player_window_title,
         player_video_path,
         start_frame_image_path,
-        video_capture_source=config.getint("app", "video_capture_source"),
-        show_capture_video=config.getboolean("app", "show_capture_video"),
         video_offset_frames=0,
     ):
         self.player_window_title = player_window_title
         self.start_frame_image_path = start_frame_image_path
-        self.video_capture_source = video_capture_source
-        self.show_capture_video = show_capture_video
+        self.show_capture_video = config.getboolean("app", "show_capture_video")
         self.autoreset = config.getboolean("app", "autoreset")
         self.enable_fceux_tas_start = config.getboolean("app", "enable_fceux_tas_start")
         self.write_capture_video = config.getboolean("app", "write_capture_video")
         self.enable_video_player = config.getboolean("app", "enable_video_player")
+        self.track_end_stage_clear_text_time = config.getboolean(
+            "app", "track_end_stage_clear_text_time"
+        )
         self.playing = False
+        self.current_time = time.time()
+        self.start_time = -1
 
+        if self.track_end_stage_clear_text_time:
+            self.last_clear_sighting_time = -1
+            self.end_stage_clear_text_template = cv2.imread(
+                config.get("app", "end_stage_clear_text_path")
+            )
         self.reset_template = cv2.imread(config.get("app", "reset_image_path"))
         self.template = cv2.imread(self.start_frame_image_path)
-        self.capture = cv2.VideoCapture(self.video_capture_source)
+        self.capture = cv2.VideoCapture(config.getint("app", "video_capture_source"))
         if not self.capture.isOpened():
             logging.info("Cannot open camera")
             exit()
@@ -46,18 +56,35 @@ class OpencvComputer:
             self.video_player = VideoPlayer(player_video_path, video_offset_frames)
 
     def tick(self):
+        self.current_time = time.time()
         ret, frame = self.capture.read()
         if not ret:
             logging.warn("Can't receive frame (stream end?). Exiting ...")
             exit()
         if self.write_capture_video:
             self.output_video.write(frame)
+        if (
+            self.track_end_stage_clear_text_time
+            and self.playing
+            and self.current_time - self.last_clear_sighting_time
+            > CLEAR_SIGHTING_DURATION_SECONDS
+            and list(
+                OpencvComputer.locate_all_opencv(
+                    self.end_stage_clear_text_template, frame
+                )
+            )
+        ):
+            self.last_clear_sighting_time = self.current_time
+            logging.info(
+                f"Cleared a level at {self.last_clear_sighting_time-self.start_time}"
+            )
         if (
             self.autoreset
             and self.playing
             and list(OpencvComputer.locate_all_opencv(self.reset_template, frame))
         ):
             self.playing = False
+            self.start_time = -1
             if self.enable_video_player:
                 self.video_player.reset()
             if self.enable_fceux_tas_start:
@@ -78,6 +105,7 @@ class OpencvComputer:
                     cv2.rectangle(frame, top_left, bottom_right, (0, 0, 255), 5)
             if results:
                 self.playing = True
+                self.start_time = time.time()
                 if self.enable_fceux_tas_start:
                     pyautogui.press("pause")
                 if self.enable_video_player:
