@@ -1,8 +1,14 @@
+from asyncio.log import logger
 from signal import signal, SIGINT
 
 from smb3_eh_manip.logging import initialize_logging
 from smb3_eh_manip.settings import config
-from smb3_eh_manip.computers import EhComputer, CalibrationComputer, TwoOneComputer
+from smb3_eh_manip.computers import (
+    EhComputer,
+    EhVcamComputer,
+    CalibrationComputer,
+    TwoOneComputer,
+)
 
 
 def handler(_signum, _frame):
@@ -15,12 +21,17 @@ def handler(_signum, _frame):
 def main():
     global computer
     initialize_logging()
-    if config.get("app", "computer") == "eh":
+    computer_name = config.get("app", "computer")
+    if computer_name == "eh":
         computer = EhComputer()
-    elif config.get("app", "computer") == "twoone":
+    elif computer_name == "twoone":
         computer = TwoOneComputer()
-    else:
+    elif computer_name == "eh_vcam":
+        computer = EhVcamComputer()
+    elif computer_name == "calibration":
         computer = CalibrationComputer()
+    else:
+        logger.warn(f"Failed to find computer {computer_name}")
     while computer is not None:
         computer.tick()
 
